"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthModule = void 0;
const msal_browser_1 = require("@azure/msal-browser");
/**
 * Configuration class for @azure/msal-browser:
 * https://azuread.github.io/microsoft-authentication-library-for-js/ref/msal-browser/modules/_src_config_configuration_.html
 */
const BASE_MSAL_CONFIG = {
    auth: { clientId: '' },
    cache: {
        cacheLocation: 'sessionStorage',
        storeAuthStateInCookie: false,
    },
    system: {
        loggerOptions: {
            loggerCallback: (level, message, containsPii) => {
                if (containsPii) {
                    return;
                }
                switch (level) {
                    case msal_browser_1.LogLevel.Error:
                        console.error(message);
                        return;
                    case msal_browser_1.LogLevel.Info:
                        console.info(message);
                        return;
                    case msal_browser_1.LogLevel.Verbose:
                        console.debug(message);
                        return;
                    case msal_browser_1.LogLevel.Warning:
                        console.warn(message);
                        return;
                }
            },
        },
    },
};
/**
 * AuthModule for application - handles authentication in app.
 */
class AuthModule {
    constructor(args) {
        const msal_config = BASE_MSAL_CONFIG;
        msal_config.auth.clientId = args.clientId;
        msal_config.auth.authority = args.authority;
        this.myMSALObj = new msal_browser_1.PublicClientApplication(msal_config);
        this.account = null;
        this.loginRequest = { scopes: [] };
    }
    getAccount() {
        // need to call getAccount here?
        const currentAccounts = this.myMSALObj.getAllAccounts();
        if (currentAccounts === null) {
            console.log('No accounts detected');
            return null;
        }
        if (currentAccounts.length > 1) {
            // Add choose account code here
            console.log('Multiple accounts detected, need to add choose account code.');
            return currentAccounts[0];
        }
        else if (currentAccounts.length === 1) {
            return currentAccounts[0];
        }
        return null;
    }
    /**
     * Checks whether we are in the middle of a redirect and handles state accordingly. Only required for redirect flows.
     *
     * https://github.com/AzureAD/microsoft-authentication-library-for-js/blob/dev/lib/msal-browser/docs/initialization.md#redirect-apis
     */
    loadAuthModule() {
        this.myMSALObj
            .handleRedirectPromise()
            .then((resp) => {
            // this.handleResponse(resp);
        })
            .catch(console.error);
    }
    // /**
    //  * Handles the response from a popup or redirect. If response is null, will check if we have any accounts and attempt to sign in.
    //  * @param response
    //  */
    // // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    // handleResponse(response: AuthenticationResult | null) {
    //   if (response !== null) {
    //     this.account = response.account;
    //   } else {
    //     this.account = this.getAccount();
    //   }
    // }
    /**
     * Callback after the response
     * @param callback
     */
    // eslint-disable-next-line @typescript-eslint/ban-types
    login(callback) {
        this.myMSALObj
            .loginPopup(this.loginRequest)
            // .then(this.handleResponse)
            .then((data) => {
            if (callback) {
                callback(data);
            }
            return data;
        })
            .catch(console.error);
    }
    /**
     * Logs out of current account.
     */
    logout(callback) {
        let account;
        if (this.account) {
            account = this.account;
        }
        const logOutRequest = { account };
        this.myMSALObj.logoutPopup(logOutRequest).then((data) => {
            if (callback) {
                callback(data);
            }
            return data;
        });
    }
}
exports.AuthModule = AuthModule;
//# sourceMappingURL=AuthModule.js.map